==> packer-plugin-docker_1.0.8.orig.tar.gz: post-processor/docker-tag/post-processor_test.go <==
package dockertag

import (
	"bytes"
	"context"
	"testing"

	"github.com/hashicorp/packer-plugin-docker/builder/docker"
	dockerimport "github.com/hashicorp/packer-plugin-docker/post-processor/docker-import"
	packersdk "github.com/hashicorp/packer-plugin-sdk/packer"
	"github.com/stretchr/testify/assert"
)

func testConfig() map[string]interface{} {
	return map[string]interface{}{
		"repository": "foo",
		"tag":        "bar,buzz",
	}
}

func testUi() *packersdk.BasicUi {
	return &packersdk.BasicUi{
		Reader: new(bytes.Buffer),
		Writer: new(bytes.Buffer),
	}
}

func TestPostProcessor_ImplementsPostProcessor(t *testing.T) {
	var _ packersdk.PostProcessor = new(PostProcessor)
}

func TestPostProcessor_PostProcess(t *testing.T) {
	driver := &docker.MockDriver{}
	p := &PostProcessor{Driver: driver}
	if err := p.Configure(testConfig()); err != nil {
		t.Fatalf("err: %s", err)
	}

	artifact := &packersdk.MockArtifact{
		BuilderIdValue: dockerimport.BuilderId,
		IdValue:        "1234567890abcdef",
	}

	result, keep, forceOverride, err := p.PostProcess(context.Background(), testUi(), artifact)
	if _, ok := result.(packersdk.Artifact); !ok {
		t.Fatal("should be instance of Artifact")
	}
	if !keep {
		t.Fatal("should keep")
	}
	if !forceOverride {
		t.Fatal("Should force keep no matter what user sets.")
	}
	if err != nil {
		t.Fatalf("err: %s", err)
	}

	if driver.TagImageCalled != 2 {
		t.Fatal("should call TagImage")
	}
	if driver.TagImageImageId != "1234567890abcdef" {
		t.Fatal("bad image id")
	}

	if driver.TagImageRepo[0] != "foo:bar" {
		t.Fatal("bad repo")
	}

	if driver.TagImageRepo[1] != "foo:buzz" {
		t.Fatal("bad repo")
	}

	if driver.TagImageForce {
		t.Fatal("bad force. force=false in default")
	}
}

func TestPostProcessor_PostProcess_Force(t *testing.T) {
	driver := &docker.MockDriver{}
	p := &PostProcessor{Driver: driver}
	c := testConfig()
	c["force"] = true
	if err := p.Configure(c); err != nil {
		t.Fatalf("err: %s", err)
	}

	artifact := &packersdk.MockArtifact{
		BuilderIdValue: dockerimport.BuilderId,
		IdValue:        "1234567890abcdef",
	}

	result, keep, forceOverride, err := p.PostProcess(context.Background(), testUi(), artifact)
	if _, ok := result.(packersdk.Artifact); !ok {
		t.Fatal("should be instance of Artifact")
	}
	if !keep {
		t.Fatal("should keep")
	}
	if !forceOverride {
		t.Fatal("Should force keep no matter what user sets.")
	}
	if err != nil {
		t.Fatalf("err: %s", err)
	}

	if driver.TagImageCalled != 2 {
		t.Fatal("should call TagImage")
	}
	if driver.TagImageImageId != "1234567890abcdef" {
		t.Fatal("bad image id")
	}
	if driver.TagImageRepo[0] != "foo:bar" {
		t.Fatal("bad repo")
	}
	if driver.TagImageRepo[1] != "foo:buzz" {
		t.Fatal("bad repo")
	}
	if !driver.TagImageForce {
		t.Fatal("bad force")
	}
}

func TestPostProcessor_PostProcess_NoTag(t *testing.T) {
	driver := &docker.MockDriver{}
	p := &PostProcessor{Driver: driver}
	c := testConfig()
	delete(c, "tag")
	if err := p.Configure(c); err != nil {
		t.Fatalf("err %s", err)
	}

	artifact := &packersdk.MockArtifact{BuilderIdValue: dockerimport.BuilderId, IdValue: "1234567890abcdef"}

	result, keep, forceOverride, err := p.PostProcess(context.Background(), testUi(), artifact)
	if _, ok := result.(packersdk.Artifact); !ok {
		t.Fatal("should be instance of Artifact")
	}
	if !keep {
		t.Fatal("should keep")
	}
	if !forceOverride {
		t.Fatal("Should force keep no matter what user sets.")
	}
	if err != nil {
		t.Fatalf("err: %s", err)
	}

	if driver.TagImageCalled != 1 {
		t.Fatal("should call TagImage")
	}
	if driver.TagImageImageId != "1234567890abcdef" {
		t.Fatal("bad image id")
	}
	if driver.TagImageRepo[0] != "foo" {
		t.Fatal("bad repo")
	}
	if driver.TagImageForce {
		t.Fatal("bad force")
	}
}

func TestPostProcessor_PostProcess_Tag_vs_Tags(t *testing.T) {
	testCases := []map[string]interface{}{
		{
			"tag":  "bar,buzz",
			"tags": []string{"bang"},
		},
		{
			"tag":  []string{"bar", "buzz"},
			"tags": []string{"bang"},
		},
		{
			"tag":  []string{"bar"},
			"tags": []string{"buzz", "bang"},
		},
	}

	for _, tc := range testCases {
		var p PostProcessor
		if err := p.Configure(tc); err != nil {
			t.Fatalf("err: %s", err)
		}
		assert.ElementsMatchf(t, p.config.Tags, []string{"bar", "buzz", "bang"},
			"tag and tags fields should be combined into tags fields. Received: %#v",
			p.config.Tags)
	}
}

==> packer-plugin-docker_1.0.9.orig.tar.gz: post-processor/docker-tag/post-processor_test.go <==
// Copyright (c) HashiCorp, Inc.
// SPDX-License-Identifier: MPL-2.0

package dockertag

import (
	"bytes"
	"context"
	"testing"

	"github.com/hashicorp/packer-plugin-docker/builder/docker"
	dockerimport "github.com/hashicorp/packer-plugin-docker/post-processor/docker-import"
	packersdk "github.com/hashicorp/packer-plugin-sdk/packer"
	"github.com/stretchr/testify/assert"
)

func testConfig() map[string]interface{} {
	return map[string]interface{}{
		"repository": "foo",
		"tag":        "bar,buzz",
	}
}

func testUi() *packersdk.BasicUi {
	return &packersdk.BasicUi{
		Reader: new(bytes.Buffer),
		Writer: new(bytes.Buffer),
	}
}

func TestPostProcessor_ImplementsPostProcessor(t *testing.T) {
	var _ packersdk.PostProcessor = new(PostProcessor)
}

func TestPostProcessor_PostProcess(t *testing.T) {
	driver := &docker.MockDriver{}
	p := &PostProcessor{Driver: driver}
	if err := p.Configure(testConfig()); err != nil {
		t.Fatalf("err: %s", err)
	}

	artifact := &packersdk.MockArtifact{
		BuilderIdValue: dockerimport.BuilderId,
		IdValue:        "1234567890abcdef",
	}

	_, keep, forceOverride, err := p.PostProcess(context.Background(), testUi(), artifact)
	if !keep {
		t.Fatal("should keep")
	}
	if !forceOverride {
		t.Fatal("Should force keep no matter what user sets.")
	}
	if err != nil {
		t.Fatalf("err: %s", err)
	}

	if driver.TagImageCalled != 2 {
		t.Fatal("should call TagImage")
	}
	if driver.TagImageImageId != "1234567890abcdef" {
		t.Fatal("bad image id")
	}

	if driver.TagImageRepo[0] != "foo:bar" {
		t.Fatal("bad repo")
	}

	if driver.TagImageRepo[1] != "foo:buzz" {
		t.Fatal("bad repo")
	}

	if driver.TagImageForce {
		t.Fatal("bad force. force=false in default")
	}
}

func TestPostProcessor_PostProcess_Force(t *testing.T) {
	driver := &docker.MockDriver{}
	p := &PostProcessor{Driver: driver}
	c := testConfig()
	c["force"] = true
	if err := p.Configure(c); err != nil {
		t.Fatalf("err: %s", err)
	}

	artifact := &packersdk.MockArtifact{
		BuilderIdValue: dockerimport.BuilderId,
		IdValue:        "1234567890abcdef",
	}

	_, keep, forceOverride, err := p.PostProcess(context.Background(), testUi(), artifact)
	if !keep {
		t.Fatal("should keep")
	}
	if !forceOverride {
		t.Fatal("Should force keep no matter what user sets.")
	}
	if err != nil {
		t.Fatalf("err: %s", err)
	}

	if driver.TagImageCalled != 2 {
		t.Fatal("should call TagImage")
	}
	if driver.TagImageImageId != "1234567890abcdef" {
		t.Fatal("bad image id")
	}
	if driver.TagImageRepo[0] != "foo:bar" {
		t.Fatal("bad repo")
	}
	if driver.TagImageRepo[1] != "foo:buzz" {
		t.Fatal("bad repo")
	}
	if !driver.TagImageForce {
		t.Fatal("bad force")
	}
}

func TestPostProcessor_PostProcess_NoTag(t *testing.T) {
	driver := &docker.MockDriver{}
	p := &PostProcessor{Driver: driver}
	c := testConfig()
	delete(c, "tag")
	if err := p.Configure(c); err != nil {
		t.Fatalf("err %s", err)
	}

	artifact := &packersdk.MockArtifact{BuilderIdValue: dockerimport.BuilderId, IdValue: "1234567890abcdef"}

	_, keep, forceOverride, err := p.PostProcess(context.Background(), testUi(), artifact)
	if !keep {
		t.Fatal("should keep")
	}
	if !forceOverride {
		t.Fatal("Should force keep no matter what user sets.")
	}
	if err != nil {
		t.Fatalf("err: %s", err)
	}

	if driver.TagImageCalled != 1 {
		t.Fatal("should call TagImage")
	}
	if driver.TagImageImageId != "1234567890abcdef" {
		t.Fatal("bad image id")
	}
	if driver.TagImageRepo[0] != "foo" {
		t.Fatal("bad repo")
	}
	if driver.TagImageForce {
		t.Fatal("bad force")
	}
}

func TestPostProcessor_PostProcess_Tag_vs_Tags(t *testing.T) {
	testCases := []map[string]interface{}{
		{
			"tag":  "bar,buzz",
			"tags": []string{"bang"},
		},
		{
			"tag":  []string{"bar", "buzz"},
			"tags": []string{"bang"},
		},
		{
			"tag":  []string{"bar"},
			"tags": []string{"buzz", "bang"},
		},
	}

	for _, tc := range testCases {
		var p PostProcessor
		if err := p.Configure(tc); err != nil {
			t.Fatalf("err: %s", err)
		}
		assert.ElementsMatchf(t, p.config.Tags, []string{"bar", "buzz", "bang"},
			"tag and tags fields should be combined into tags fields. Received: %#v",
			p.config.Tags)
	}
}
